From 33833e1bf40f089db0d8bf3deba219f3f9c939d9 Mon Sep 17 00:00:00 2001
From: uz <uz@b7a2c559-68d2-44c3-8de9-860c34a00d81>
Date: Mon, 7 Jan 2013 19:32:55 +0000
Subject: [PATCH] Declare more internal TGI kernel variables. Not really usable
 for standard programs, but can be useful for testing.

git-svn-id: svn://svn.cc65.org/cc65/trunk@5956 b7a2c559-68d2-44c3-8de9-860c34a00d81
---
 include/tgi/tgi-kernel.h | 32 ++++++++++++++++++++------------
 1 file changed, 20 insertions(+), 12 deletions(-)

diff --git a/include/tgi/tgi-kernel.h b/include/tgi/tgi-kernel.h
index d6d58a85c..3d0bbda84 100644
--- a/include/tgi/tgi-kernel.h
+++ b/include/tgi/tgi-kernel.h
@@ -6,7 +6,7 @@
 /*                                                                           */
 /*                                                                           */
 /*                                                                           */
-/* (C) 2002-2009, Ullrich von Bassewitz                                      */
+/* (C) 2002-2012, Ullrich von Bassewitz                                      */
 /*                Roemerstrasse 52                                           */
 /*                D-70794 Filderstadt                                        */
 /* EMail:         uz@cc65.org                                                */
@@ -45,17 +45,25 @@
 
 
 /* TGI kernel variables */
-extern void*   	        tgi_drv;       	/* Pointer to driver */
-extern unsigned char  	tgi_error;     	/* Last error code */
-extern unsigned char    tgi_gmode;      /* Flag: Graphics mode active */
-extern int              tgi_curx;       /* Current drawing cursor X */
-extern int              tgi_cury;       /* Current drawing cursor Y */
-extern unsigned char    tgi_color;      /* Current drawing color */
-extern unsigned         tgi_xres;       /* X resolution of the current mode */
-extern unsigned         tgi_yres;       /* Y resolution of the current mode */
-extern unsigned char    tgi_colorcount; /* Number of available colors */
-extern unsigned char    tgi_pagecount;  /* Number of available screens */
-extern unsigned         tgi_aspectratio;/* Aspect ratio as fixed point 8.8 */
+extern void*   	     tgi_drv;           /* Pointer to driver */
+extern unsigned char tgi_error;         /* Last error code */
+extern unsigned char tgi_gmode;         /* Flag: Graphics mode active */
+extern int           tgi_curx;          /* Current drawing cursor X */
+extern int           tgi_cury;          /* Current drawing cursor Y */
+extern unsigned char tgi_color;         /* Current drawing color */
+extern unsigned char tgi_font;          /* Current font type */
+extern unsigned      tgi_xres;          /* X resolution of the current mode */
+extern unsigned      tgi_yres;          /* Y resolution of the current mode */
+extern unsigned char tgi_colorcount;    /* Number of available colors */
+extern unsigned char tgi_pagecount;     /* Number of available screens */
+extern unsigned char tgi_fontwidth;     /* System font width in pixels */
+extern unsigned char tgi_fontheight;    /* System font height in pixels */
+extern unsigned      tgi_aspectratio;   /* Aspect ratio as fixed point 8.8 */
+extern unsigned char tgi_flags;         /* TGI driver flags */
+extern unsigned      tgi_textscalew[2]; /* Vector/bitmap font scale 8.8 */
+extern unsigned      tgi_textscaleh[2]; /* Vector/bitmap font scale 8.8 */
+extern unsigned      tgi_charwidth;     /* Width of scaled bitmap font */
+extern unsigned      tgi_charheight;    /* Height of scaled bitmap font */